@@ -7,14 +7,14 @@ use Carp;
 #==================================================================
 # Author    : Djibril Ousmanou
 # Copyright : 2010
-# Update    : 22/05/2010 19:11:07
+# Update    : 19/06/2010 22:47:48
 # AIM       : Create area graph
 #==================================================================
 
 use vars qw($VERSION);
-$VERSION = '1.08';
+$VERSION = '1.09';
 
-use base qw/Tk::Derived Tk::Canvas/;
+use base qw/Tk::Derived Tk::Canvas::GradientColor/;
 use Tk::Balloon;
 
 use Tk::ForDummies::Graph::Utils qw (:DUMMIES  :DISPLAY);
@@ -31,7 +31,14 @@ sub Populate {
 
   $CompositeWidget->SUPER::Populate($RefParameters);
 
-  $CompositeWidget->Advertise( 'canvas' => $CompositeWidget );
+  $CompositeWidget->Advertise( 'GradientColor' => $CompositeWidget );
+  $CompositeWidget->Advertise( 'canvas'        => $CompositeWidget->SUPER::Canvas );
+  $CompositeWidget->Advertise( 'Canvas'        => $CompositeWidget->SUPER::Canvas );
+
+  # remove highlightthickness if necessary
+  unless ( exists $RefParameters->{-highlightthickness} ) {
+    $CompositeWidget->configure( -highlightthickness => 0 );
+  }
 
   # ConfigSpecs
   $CompositeWidget->ConfigSpecs(
@@ -117,6 +124,7 @@ sub Populate {
 
   # recreate graph after widget resize
   $CompositeWidget->enabled_automatic_redraw();
+  $CompositeWidget->disabled_gradientcolor();
 }
 
 sub _Balloon {
@@ -182,7 +190,6 @@ sub _Balloon {
           -width => $CompositeWidget->cget( -linewidth )
             + $CompositeWidget->{RefInfoDummies}->{Balloon}{MorePixelSelected},
         );
-
       }
     );
 
@@ -199,7 +206,6 @@ sub _Balloon {
         # Allow dash line to display
         $CompositeWidget->itemconfigure( $CompositeWidget->{RefInfoDummies}->{TAGS}{DashLines},
           -fill => 'black', );
-
       }
     );
   }
@@ -372,13 +378,17 @@ sub _ViewLegend {
       + $CompositeWidget->{RefInfoDummies}->{Axis}{Xaxis}{xlabelHeight};
 
     $CompositeWidget->createText(
-      $xLegendTitle, $yLegendTitle,
+      $xLegendTitle,
+      $yLegendTitle,
       -text   => $LegendTitle,
       -anchor => 'nw',
       -font   => $titlefont,
       -fill   => $titlecolor,
       -width  => $CompositeWidget->{RefInfoDummies}->{Axis}{Xaxis}{Width},
-      -tags   => $CompositeWidget->{RefInfoDummies}->{TAGS}{TitleLegend},
+      -tags   => [
+        $CompositeWidget->{RefInfoDummies}->{TAGS}{TitleLegend},
+        $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTagsDummiesGraph},
+      ],
     );
   }
 
@@ -430,14 +440,14 @@ sub _ViewLegend {
         $x1Cube, $y1Cube, $x2Cube, $y2Cube,
         -fill    => $LineColor,
         -outline => $LineColor,
-        -tags    => $Tag,
+        -tags    => [ $Tag, $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTagsDummiesGraph}, ],
       );
 
       my $Id = $CompositeWidget->createText(
         $xText, $yText,
         -text   => $NewLegend,
         -anchor => 'nw',
-        -tags   => $Tag,
+        -tags   => [ $Tag, $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTagsDummiesGraph}, ],
       );
       if ($legendfont) {
         $CompositeWidget->itemconfigure( $Id, -font => $legendfont, );
@@ -484,8 +494,13 @@ sub _ViewLegend {
     $x2Box = $InfoLegendTitle[2] + 2;
   }
   my $y2Box = $y1Box + $CompositeWidget->{RefInfoDummies}->{Legend}{Height};
-  $CompositeWidget->createRectangle( $x1Box, $y1Box, $x2Box, $y2Box,
-    -tags => $CompositeWidget->{RefInfoDummies}->{TAGS}{BoxLegend}, );
+  $CompositeWidget->createRectangle(
+    $x1Box, $y1Box, $x2Box, $y2Box,
+    -tags => [
+      $CompositeWidget->{RefInfoDummies}->{TAGS}{BoxLegend},
+      $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTagsDummiesGraph},
+    ],
+  );
 
   return;
 }
@@ -545,7 +560,8 @@ sub _axis {
     $CompositeWidget->{RefInfoDummies}->{Axis}{CyMax},
     -tags => [
       $CompositeWidget->{RefInfoDummies}->{TAGS}{yAxis},
-      $CompositeWidget->{RefInfoDummies}->{TAGS}{AllAXIS}
+      $CompositeWidget->{RefInfoDummies}->{TAGS}{AllAXIS},
+      $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTagsDummiesGraph},
     ],
   );
 
@@ -566,7 +582,8 @@ sub _axis {
     $CompositeWidget->{RefInfoDummies}->{Axis}{CyMin},
     -tags => [
       $CompositeWidget->{RefInfoDummies}->{TAGS}{xAxis},
-      $CompositeWidget->{RefInfoDummies}->{TAGS}{AllAXIS}
+      $CompositeWidget->{RefInfoDummies}->{TAGS}{AllAXIS},
+      $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTagsDummiesGraph},
     ],
   );
 
@@ -602,7 +619,8 @@ sub _axis {
       $CompositeWidget->{RefInfoDummies}->{Axis}{Cy0},
       -tags => [
         $CompositeWidget->{RefInfoDummies}->{TAGS}{xAxis0},
-        $CompositeWidget->{RefInfoDummies}->{TAGS}{AllAXIS}
+        $CompositeWidget->{RefInfoDummies}->{TAGS}{AllAXIS},
+        $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTagsDummiesGraph},
       ],
     );
   }
@@ -670,7 +688,8 @@ sub _xtick {
         $Xtickx1, $Xticky1, $Xtickx2, $Xticky2,
         -tags => [
           $CompositeWidget->{RefInfoDummies}->{TAGS}{xTick},
-          $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTick}
+          $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTick},
+          $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTagsDummiesGraph},
         ],
       );
       $CompositeWidget->createText(
@@ -680,7 +699,8 @@ sub _xtick {
         -fill => $xvaluecolor,
         -tags => [
           $CompositeWidget->{RefInfoDummies}->{TAGS}{xValues},
-          $CompositeWidget->{RefInfoDummies}->{TAGS}{AllValues}
+          $CompositeWidget->{RefInfoDummies}->{TAGS}{AllValues},
+          $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTagsDummiesGraph},
         ],
       );
     }
@@ -759,8 +779,12 @@ sub _ViewData {
 
     $CompositeWidget->createPolygon(
       @PointsData,
-      -fill    => $LineColor,
-      -tags    => [ $tag_area, $tag, $CompositeWidget->{RefInfoDummies}->{TAGS}{AllData} ],
+      -fill => $LineColor,
+      -tags => [
+        $tag_area, $tag,
+        $CompositeWidget->{RefInfoDummies}->{TAGS}{AllData},
+        $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTagsDummiesGraph},
+      ],
       -width   => $CompositeWidget->cget( -linewidth ),
       -outline => $outlinearea,
     );
@@ -789,6 +813,7 @@ sub _ViewData {
             $tag,
             $CompositeWidget->{RefInfoDummies}->{TAGS}{AllData},
             $CompositeWidget->{RefInfoDummies}->{TAGS}{DashLines},
+            $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTagsDummiesGraph},
           ],
         );
         $i++;
@@ -933,6 +958,8 @@ Tk::ForDummies::Graph::Areas - Extension of Canvas widget to create area lines g
 Tk::ForDummies::Graph::Areas is an extension of the Canvas widget. It is an easy way to build an 
 interactive Area line graph into your Perl Tk widget. The module is written entirely in Perl/Tk.
 
+You can set a background gradient color.
+
 You can change the color, font of title, labels (x and y) of the graph.
 You can set an interactive legend.  
 The axes can be automatically scaled or set by the code. 
@@ -941,6 +968,22 @@ With this module it is possible to plot quantitative variables according to qual
 When the mouse cursor passes over a plotted line or its entry in the legend, 
 the line and its entry will be turned to a color (that you can change) to help identify it. 
 
+=head1 BACKGROUND GRADIENT COLOR
+
+You can set a background gradient color by using all methods of L<Tk::Canvas::GradientColor>. By 
+default, it is not enabled.
+
+To enabled background gradient color the first time, you firstly have to call B<enabled_gradientcolor> method and configure 
+your color and type of gradient with B<set_gradientcolor>.
+
+  $GraphDummies->enabled_gradientcolor();
+  $GraphDummies->set_gradientcolor(
+      -start_color => '#6585ED',
+      -end_color   => '#FFFFFF',
+  );
+
+Please, read L<Tk::Canvas::GradientColor/"WIDGET-SPECIFIC METHODS"> documentation to know all available configurations.
+
 =head1 STANDARD OPTIONS
 
 B<-background>          B<-borderwidth>	      B<-closeenough>	         B<-confine>
