@@ -7,14 +7,14 @@ use Carp;
 #==================================================================
 # Author    : Djibril Ousmanou
 # Copyright : 2010
-# Update    : 22/05/2010 19:11:16
+# Update    : 19/06/2010 22:47:33
 # AIM       : Create bars graph
 #==================================================================
 
 use vars qw($VERSION);
-$VERSION = '1.09';
+$VERSION = '1.10';
 
-use base qw/Tk::Derived Tk::Canvas/;
+use base qw/Tk::Derived Tk::Canvas::GradientColor/;
 use Tk::Balloon;
 
 use Tk::ForDummies::Graph::Utils qw (:DUMMIES);
@@ -31,7 +31,14 @@ sub Populate {
 
   $CompositeWidget->SUPER::Populate($RefParameters);
 
-  $CompositeWidget->Advertise( 'canvas' => $CompositeWidget );
+  $CompositeWidget->Advertise( 'GradientColor' => $CompositeWidget );
+  $CompositeWidget->Advertise( 'canvas'        => $CompositeWidget->SUPER::Canvas );
+  $CompositeWidget->Advertise( 'Canvas'        => $CompositeWidget->SUPER::Canvas );
+
+  # remove highlightthickness if necessary
+  unless ( exists $RefParameters->{-highlightthickness} ) {
+    $CompositeWidget->configure( -highlightthickness => 0 );
+  }
 
   $CompositeWidget->ConfigSpecs(
     -title      => [ 'PASSIVE', 'Title',      'Title',      undef ],
@@ -119,6 +126,7 @@ sub Populate {
 
   # recreate graph after widget resize
   $CompositeWidget->enabled_automatic_redraw();
+  $CompositeWidget->disabled_gradientcolor();
 }
 
 sub _Balloon {
@@ -390,13 +398,17 @@ sub _ViewLegend {
       + $CompositeWidget->{RefInfoDummies}->{Axis}{Xaxis}{xlabelHeight};
 
     $CompositeWidget->createText(
-      $xLegendTitle, $yLegendTitle,
+      $xLegendTitle,
+      $yLegendTitle,
       -text   => $LegendTitle,
       -anchor => 'nw',
       -font   => $titlefont,
       -fill   => $titlecolor,
       -width  => $CompositeWidget->{RefInfoDummies}->{Axis}{Xaxis}{Width},
-      -tags   => $CompositeWidget->{RefInfoDummies}->{TAGS}{TitleLegend},
+      -tags   => [
+        $CompositeWidget->{RefInfoDummies}->{TAGS}{TitleLegend},
+        $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTagsDummiesGraph},
+      ],
     );
   }
 
@@ -449,14 +461,14 @@ sub _ViewLegend {
         $x1Cube, $y1Cube, $x2Cube, $y2Cube,
         -fill    => $LineColor,
         -outline => $LineColor,
-        -tags    => $Tag,
+        -tags    => [ $Tag, $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTagsDummiesGraph}, ],
       );
 
       my $Id = $CompositeWidget->createText(
         $xText, $yText,
         -text   => $NewLegend,
         -anchor => 'nw',
-        -tags   => $Tag,
+        -tags   => [ $Tag, $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTagsDummiesGraph}, ],
       );
       if ($legendfont) {
         $CompositeWidget->itemconfigure( $Id, -font => $legendfont, );
@@ -500,8 +512,13 @@ sub _ViewLegend {
     $x2Box = $InfoLegendTitle[2] + 2;
   }
   my $y2Box = $y1Box + $CompositeWidget->{RefInfoDummies}->{Legend}{Height};
-  $CompositeWidget->createRectangle( $x1Box, $y1Box, $x2Box, $y2Box,
-    -tags => $CompositeWidget->{RefInfoDummies}->{TAGS}{BoxLegend}, );
+  $CompositeWidget->createRectangle(
+    $x1Box, $y1Box, $x2Box, $y2Box,
+    -tags => [
+      $CompositeWidget->{RefInfoDummies}->{TAGS}{BoxLegend},
+      $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTagsDummiesGraph},
+    ],
+  );
 
   return;
 }
@@ -561,7 +578,8 @@ sub _axis {
     $CompositeWidget->{RefInfoDummies}->{Axis}{CyMax},
     -tags => [
       $CompositeWidget->{RefInfoDummies}->{TAGS}{yAxis},
-      $CompositeWidget->{RefInfoDummies}->{TAGS}{AllAXIS}
+      $CompositeWidget->{RefInfoDummies}->{TAGS}{AllAXIS},
+      $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTagsDummiesGraph},
     ],
   );
 
@@ -580,7 +598,8 @@ sub _axis {
     $CompositeWidget->{RefInfoDummies}->{Axis}{CyMin},
     -tags => [
       $CompositeWidget->{RefInfoDummies}->{TAGS}{xAxis},
-      $CompositeWidget->{RefInfoDummies}->{TAGS}{AllAXIS}
+      $CompositeWidget->{RefInfoDummies}->{TAGS}{AllAXIS},
+      $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTagsDummiesGraph},
     ],
   );
 
@@ -616,7 +635,8 @@ sub _axis {
       $CompositeWidget->{RefInfoDummies}->{Axis}{Cy0},
       -tags => [
         $CompositeWidget->{RefInfoDummies}->{TAGS}{xAxis0},
-        $CompositeWidget->{RefInfoDummies}->{TAGS}{AllAXIS}
+        $CompositeWidget->{RefInfoDummies}->{TAGS}{AllAXIS},
+        $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTagsDummiesGraph},
       ],
     );
   }
@@ -684,7 +704,8 @@ sub _xtick {
         $Xtickx1, $Xticky1, $Xtickx2, $Xticky2,
         -tags => [
           $CompositeWidget->{RefInfoDummies}->{TAGS}{xTick},
-          $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTick}
+          $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTick},
+          $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTagsDummiesGraph},
         ],
       );
 
@@ -707,7 +728,8 @@ sub _xtick {
         -fill => $xvaluecolor,
         -tags => [
           $CompositeWidget->{RefInfoDummies}->{TAGS}{xValues},
-          $CompositeWidget->{RefInfoDummies}->{TAGS}{AllValues}
+          $CompositeWidget->{RefInfoDummies}->{TAGS}{AllValues},
+          $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTagsDummiesGraph},
         ],
       );
     }
@@ -819,17 +841,26 @@ sub _ViewData {
 
       $CompositeWidget->createRectangle(
         $x0, $y0, $x, $y,
-        -fill    => $LineColor,
-        -tags    => [ $tag, $tag2, $CompositeWidget->{RefInfoDummies}->{TAGS}{AllData} ],
+        -fill => $LineColor,
+        -tags => [
+          $tag, $tag2,
+          $CompositeWidget->{RefInfoDummies}->{TAGS}{AllData},
+          $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTagsDummiesGraph},
+        ],
         -width   => $CompositeWidget->cget( -linewidth ),
         -outline => $outlinebar,
       );
       if ( $showvalues == 1 ) {
         $CompositeWidget->createText(
-          $x0 + ( $x - $x0 ) / 2, $y - 8,
+          $x0 + ( $x - $x0 ) / 2,
+          $y - 8,
           -text => $data,
           -font => $CompositeWidget->{RefInfoDummies}->{Font}{DefaultBarValues},
-          -tags => [ $tag, $CompositeWidget->{RefInfoDummies}->{TAGS}{BarValues} ],
+          -tags => [
+            $tag,
+            $CompositeWidget->{RefInfoDummies}->{TAGS}{BarValues},
+            $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTagsDummiesGraph},
+          ],
         );
       }
 
@@ -982,6 +1013,8 @@ Tk::ForDummies::Graph::Bars - Extension of Canvas widget to create bars graph.
 Tk::ForDummies::Graph::Bars is an extension of the Canvas widget. It is an easy way to build an 
 interactive bar graph into your Perl Tk widget. The module is written entirely in Perl/Tk.
 
+You can set a background gradient color.
+
 You can change the color, font of title, labels (x and y) of the graph.
 You can set an interactive legend.  
 The axes can be automatically scaled or set by the code. 
@@ -991,6 +1024,22 @@ the bar and its entry will be turned to a color (that you can change) to help id
 
 You can use 3 methods to zoom (vertically, horizontally or both).
 
+=head1 BACKGROUND GRADIENT COLOR
+
+You can set a background gradient color by using all methods of L<Tk::Canvas::GradientColor>. By 
+default, it is not enabled.
+
+To enabled background gradient color the first time, you firstly have to call B<enabled_gradientcolor> method and configure 
+your color and type of gradient with B<set_gradientcolor>.
+
+  $GraphDummies->enabled_gradientcolor();
+  $GraphDummies->set_gradientcolor(
+      -start_color => '#6585ED',
+      -end_color   => '#FFFFFF',
+  );
+
+Please, read L<Tk::Canvas::GradientColor/"WIDGET-SPECIFIC METHODS"> documentation to know all available configurations.
+
 =head1 STANDARD OPTIONS
 
 B<-background>          B<-borderwidth>	      B<-closeenough>	         B<-confine>
