@@ -7,14 +7,14 @@ use Carp;
 #==================================================================
 # Author    : Djibril Ousmanou
 # Copyright : 2010
-# Update    : 22/05/2010 19:11:54
+# Update    : 19/06/2010 22:47:12
 # AIM       : Create line graph
 #==================================================================
 
 use vars qw($VERSION);
-$VERSION = '1.10';
+$VERSION = '1.11';
 
-use base qw/Tk::Derived Tk::Canvas/;
+use base qw/ Tk::Derived Tk::Canvas::GradientColor /;
 use Tk::Balloon;
 
 use Tk::ForDummies::Graph::Utils qw / :DUMMIES :DISPLAY /;
@@ -31,7 +31,14 @@ sub Populate {
 
   $CompositeWidget->SUPER::Populate($RefParameters);
 
-  $CompositeWidget->Advertise( 'canvas' => $CompositeWidget );
+  $CompositeWidget->Advertise( 'GradientColor' => $CompositeWidget->SUPER::GradientColor );
+  $CompositeWidget->Advertise( 'canvas'        => $CompositeWidget->SUPER::Canvas );
+  $CompositeWidget->Advertise( 'Canvas'        => $CompositeWidget->SUPER::Canvas );
+
+  # remove highlightthickness if necessary
+  unless ( exists $RefParameters->{-highlightthickness} ) {
+    $CompositeWidget->configure( -highlightthickness => 0 );
+  }
 
   # ConfigSpecs
   $CompositeWidget->ConfigSpecs(
@@ -119,13 +126,13 @@ sub Populate {
     -pointline  => [ 'PASSIVE', 'Pointline',  'PointLine',  0 ],
     -markersize => [ 'PASSIVE', 'Markersize', 'MarkerSize', 8 ],
     -markers => [ 'PASSIVE', 'Markers', 'Markers', [ 1 .. 8 ] ],
-
   );
 
   $CompositeWidget->Delegates( DEFAULT => $CompositeWidget, );
 
   # recreate graph after widget resize
   $CompositeWidget->enabled_automatic_redraw();
+  $CompositeWidget->disabled_gradientcolor();
 }
 
 sub _Balloon {
@@ -393,13 +400,17 @@ sub _ViewLegend {
       + $CompositeWidget->{RefInfoDummies}->{Axis}{Xaxis}{xlabelHeight};
 
     $CompositeWidget->createText(
-      $xLegendTitle, $yLegendTitle,
+      $xLegendTitle,
+      $yLegendTitle,
       -text   => $LegendTitle,
       -anchor => 'nw',
       -font   => $titlefont,
       -fill   => $titlecolor,
       -width  => $CompositeWidget->{RefInfoDummies}->{Axis}{Xaxis}{Width},
-      -tags   => $CompositeWidget->{RefInfoDummies}->{TAGS}{TitleLegend},
+      -tags   => [
+        $CompositeWidget->{RefInfoDummies}->{TAGS}{TitleLegend},
+        $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTagsDummiesGraph},
+      ],
     );
   }
 
@@ -467,7 +478,7 @@ sub _ViewLegend {
         }
         my $x = $x1Cube + ( ( $x2Cube - $x1Cube ) / 2 );
         my $y = $y1Cube + ( ( $y2Cube - $y1Cube ) / 2 );
-        $Option{-tags} = $Tag;
+        $Option{-tags} = [ $Tag, $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTagsDummiesGraph}, ];
         $CompositeWidget->_CreateType(
           x      => $x,
           y      => $y,
@@ -482,7 +493,7 @@ sub _ViewLegend {
           $x1Cube, $y1Cube, $x2Cube, $y2Cube,
           -fill    => $LineColor,
           -outline => $LineColor,
-          -tags    => $Tag,
+          -tags    => [ $Tag, $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTagsDummiesGraph}, ],
         );
 
       }
@@ -491,7 +502,7 @@ sub _ViewLegend {
         $xText, $yText,
         -text   => $NewLegend,
         -anchor => 'nw',
-        -tags   => $Tag,
+        -tags   => [ $Tag, $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTagsDummiesGraph}, ],
       );
       if ($legendfont) {
         $CompositeWidget->itemconfigure( $Id, -font => $legendfont, );
@@ -538,8 +549,13 @@ sub _ViewLegend {
     $x2Box = $InfoLegendTitle[2] + 2;
   }
   my $y2Box = $y1Box + $CompositeWidget->{RefInfoDummies}->{Legend}{Height};
-  $CompositeWidget->createRectangle( $x1Box, $y1Box, $x2Box, $y2Box,
-    -tags => $CompositeWidget->{RefInfoDummies}->{TAGS}{BoxLegend}, );
+  $CompositeWidget->createRectangle(
+    $x1Box, $y1Box, $x2Box, $y2Box,
+    -tags => [
+      $CompositeWidget->{RefInfoDummies}->{TAGS}{BoxLegend},
+      $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTagsDummiesGraph},
+    ]
+  );
 
   return;
 }
@@ -599,7 +615,8 @@ sub _axis {
     $CompositeWidget->{RefInfoDummies}->{Axis}{CyMax},
     -tags => [
       $CompositeWidget->{RefInfoDummies}->{TAGS}{yAxis},
-      $CompositeWidget->{RefInfoDummies}->{TAGS}{AllAXIS}
+      $CompositeWidget->{RefInfoDummies}->{TAGS}{AllAXIS},
+      $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTagsDummiesGraph},
     ],
   );
 
@@ -620,7 +637,8 @@ sub _axis {
     $CompositeWidget->{RefInfoDummies}->{Axis}{CyMin},
     -tags => [
       $CompositeWidget->{RefInfoDummies}->{TAGS}{xAxis},
-      $CompositeWidget->{RefInfoDummies}->{TAGS}{AllAXIS}
+      $CompositeWidget->{RefInfoDummies}->{TAGS}{AllAXIS},
+      $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTagsDummiesGraph},
     ],
   );
 
@@ -656,7 +674,8 @@ sub _axis {
       $CompositeWidget->{RefInfoDummies}->{Axis}{Cy0},
       -tags => [
         $CompositeWidget->{RefInfoDummies}->{TAGS}{xAxis0},
-        $CompositeWidget->{RefInfoDummies}->{TAGS}{AllAXIS}
+        $CompositeWidget->{RefInfoDummies}->{TAGS}{AllAXIS},
+        $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTagsDummiesGraph},
       ],
     );
   }
@@ -724,7 +743,8 @@ sub _xtick {
         $Xtickx1, $Xticky1, $Xtickx2, $Xticky2,
         -tags => [
           $CompositeWidget->{RefInfoDummies}->{TAGS}{xTick},
-          $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTick}
+          $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTick},
+          $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTagsDummiesGraph},
         ],
       );
       $CompositeWidget->createText(
@@ -734,7 +754,8 @@ sub _xtick {
         -fill => $xvaluecolor,
         -tags => [
           $CompositeWidget->{RefInfoDummies}->{TAGS}{xValues},
-          $CompositeWidget->{RefInfoDummies}->{TAGS}{AllValues}
+          $CompositeWidget->{RefInfoDummies}->{TAGS}{AllValues},
+          $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTagsDummiesGraph},
         ],
       );
     }
@@ -800,8 +821,12 @@ sub _ViewDataLines {
 
     $CompositeWidget->createLine(
       @PointsData,
-      -fill   => $LineColor,
-      -tags   => [ $tag, $CompositeWidget->{RefInfoDummies}->{TAGS}{AllData} ],
+      -fill => $LineColor,
+      -tags => [
+        $tag,
+        $CompositeWidget->{RefInfoDummies}->{TAGS}{AllData},
+        $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTagsDummiesGraph},
+      ],
       -width  => $CompositeWidget->cget( -linewidth ),
       -smooth => $bezier,
       -dash   => $dash,
@@ -886,7 +911,11 @@ sub _ViewDataPoints {
         - ( $data * $CompositeWidget->{RefInfoDummies}->{Axis}{Yaxis}{HeightUnit} );
 
       my %Option = (
-        -tags  => [ $tag, $CompositeWidget->{RefInfoDummies}->{TAGS}{AllData} ],
+        -tags => [
+          $tag,
+          $CompositeWidget->{RefInfoDummies}->{TAGS}{AllData},
+          $CompositeWidget->{RefInfoDummies}->{TAGS}{AllTagsDummiesGraph},
+        ],
         -width => $CompositeWidget->cget( -linewidth ),
       );
       my $RefType = $CompositeWidget->_GetMarkerType($NumMarker);
@@ -1045,6 +1074,8 @@ Tk::ForDummies::Graph::Lines - Extension of Canvas widget to create a line graph
 Tk::ForDummies::Graph::Lines is an extension of the Canvas widget. It is an easy way to build an 
 interactive line graph into your Perl Tk widget. The module is written entirely in Perl/Tk.
 
+You can set a background gradient color.
+
 You can change the color, font of title, labels (x and y) of the graph.
 You can set an interactive legend.  
 The axes can be automatically scaled or set by the code. 
@@ -1055,6 +1086,22 @@ the line and its entry will be turned to a color (that you can change) to help i
 
 You can use 3 methods to zoom (vertically, horizontally or both).
 
+=head1 BACKGROUND GRADIENT COLOR
+
+You can set a background gradient color by using all methods of L<Tk::Canvas::GradientColor>. By 
+default, it is not enabled.
+
+To enabled background gradient color the first time, you firstly have to call B<enabled_gradientcolor> method and configure 
+your color and type of gradient with B<set_gradientcolor>.
+
+  $GraphDummies->enabled_gradientcolor();
+  $GraphDummies->set_gradientcolor(
+      -start_color => '#6585ED',
+      -end_color   => '#FFFFFF',
+  );
+
+Please, read L<Tk::Canvas::GradientColor/"WIDGET-SPECIFIC METHODS"> documentation to know all available configurations.
+
 =head1 STANDARD OPTIONS
 
 B<-background>          B<-borderwidth>	      B<-closeenough>	         B<-confine>
@@ -1070,7 +1117,7 @@ B<-yscrollincrement>
 Many options allow you to configure your graph as you want. 
 The default configuration is already OK, but you can change it.
 
-=head3 Options for all lines graph
+=head2 Options for all lines graph
 
 =over 4
 
@@ -1563,7 +1610,7 @@ will have the color of the first array case (red).
 
 =back
 
-=head3 Options for spline lines graph
+=head2 Options for spline lines graph
 
 =over 4
 
@@ -1596,7 +1643,7 @@ Default : B<0>
 =back
 
 
-=head3 Options for point lines graph
+=head2 Options for point lines graph
 
 These options are specific to point lines graph creation.
 
